// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// FAUVART Sbastien	<seb.fauvart@free.fr>
// Mon May 19 12:57:45 2003


#include "../include/application.h"

int oldObjectID, ObjectID;
int Flag_RetrieveObjectID, Flag_Draw_Menu, Flag_Draw_Info;
int Flag_Difficulte, Flag_Aide, Flag_Son, Flag_Style, Flag_Langue;


static CInitDisplay     *Othello_InitDisplay = NULL;
static CDisplay         *Othello_Display     = NULL;
static CTexture         *Othello_Texture     = NULL;
static CEvent           *Othello_Event       = NULL;
static CGame            *Othello_Game        = NULL;
static CGui             *Othello_Gui         = NULL;


CApplication::CApplication()
{
    
    Othello_InitDisplay = new CInitDisplay;
    Othello_Display     = new CDisplay;
    Othello_Texture     = new CTexture;
    Othello_Event       = new CEvent;
    Othello_Game        = new CGame;
    Othello_Gui         = new CGui;

    Init_Application();
    
}

void CApplication::Init_Application()
{
    window_width = 640;
    window_height = 480;
    Flag_RetrieveObjectID = 0;
    Flag_Draw_Menu = 1;
    Flag_Draw_Info = 0;
}

int CApplication::Go()
{
    if ( Othello_InitDisplay->initSDL(window_width, window_height, 16, 0, 0, 0) )
      Quit();

    if ( Othello_Texture->InitTextures() )
      Quit();

    MainLoop();

    Quit();

    return 0;

}


void CApplication::MainLoop(void)
{
    bool done = false;
    SDL_Event event;

    while(! done)
    {
        while( SDL_PollEvent(& event) )
        {
            switch ( event.type )
            {
                case SDL_QUIT :
                    done = true;
                    break;

                case SDL_KEYDOWN :
                    Othello_Event->KeyPressed( &event.key.keysym );
                    break;

                case SDL_VIDEORESIZE :
                    Othello_InitDisplay->resizeGLScene(event.resize.w, event.resize.h, 16);
                    break;

                case SDL_MOUSEBUTTONDOWN :
                    ObjectID = RetrieveObjectID(event.motion.x, event.motion.y);
                    if(event.button.button == SDL_BUTTON_RIGHT)
                      Othello_Event->MouseButtonRightDown(Othello_Game);
                      
                    if(event.button.button == SDL_BUTTON_LEFT)
                      Othello_Event->MouseButtonLeftDown(Othello_Game);
                    break;

                case SDL_MOUSEBUTTONUP :
                    ObjectID = RetrieveObjectID(event.motion.x, event.motion.y);
                    if(event.button.button == SDL_BUTTON_RIGHT)
                    Othello_Event->MouseButtonRightUp(Othello_Game);

                    if(event.button.button == SDL_BUTTON_LEFT)
                    Othello_Event->MouseButtonLeftUp(Othello_Game);
                    break;

                case SDL_MOUSEMOTION :
                    ObjectID = RetrieveObjectID(event.motion.x, event.motion.y);
                    Othello_Event->MouseMotion(event.motion.x, event.motion.y, Othello_Game);
                    break;

                default:
                    break;
            }  // switch ( event.type )

        }  // while( SDL_PollEvent(& event) )

        RenderScene();
        oldObjectID = ObjectID;
        
    }  // while(!done)

}

void CApplication::RenderScene()
{
  
    Othello_Display->PreRendu();

    glPushMatrix();
      glRotatef(board_rotate_x, 1.0f, 0.0f, 0.0f);
      glRotatef(board_rotate_y, 0.0f, 1.0f, 0.0f);
      glScalef(0.75f, 0.75f, 0.75f);
      glTranslatef(-4.0f, 0.0f, -4.0f);

      if((Flag_RetrieveObjectID == 0) && (Flag_Draw_Menu == 0))
        Othello_Display->DrawUnderBoard();

      if(Flag_Draw_Menu == 0)    
        Othello_Display->DrawBoard(Othello_Game->gameboard);

    glPopMatrix();

    if(Flag_Draw_Menu == 1)
      Othello_Gui->DrawMenu();

    if( (Flag_Draw_Info == 1) && (Flag_Draw_Menu == 0) )
      Othello_Gui->DrawInfo();

    Othello_Display->PostRendu();
    
}

int CApplication::RetrieveObjectID(int x, int y)
{
    int objectsFound = 0;
    int viewportCoords[4] = {0};

    unsigned int selectBuffer[32] = {0};

    glSelectBuffer(32, selectBuffer);

    glGetIntegerv(GL_VIEWPORT, viewportCoords);

    glMatrixMode(GL_PROJECTION);

    glPushMatrix();

        glRenderMode(GL_SELECT);

        glLoadIdentity();

        gluPickMatrix(x, viewportCoords[3] - y, 2, 2, viewportCoords);

        gluPerspective(45.0f,(float)window_width/(float)window_height,0.1f,150.0f);

        glMatrixMode(GL_MODELVIEW);

        Flag_RetrieveObjectID = 1;

        RenderScene();

        Flag_RetrieveObjectID = 0;

        objectsFound = glRenderMode(GL_RENDER);

        glMatrixMode(GL_PROJECTION);

    glPopMatrix();

    glMatrixMode(GL_MODELVIEW);

    if (objectsFound > 0)
    {
        unsigned int lowestDepth = selectBuffer[1];
        int selectedObject = selectBuffer[3];

        for(int i = 1; i < objectsFound; i++)
        {
            if(selectBuffer[(i * 4) + 1] < lowestDepth)
            {
                lowestDepth = selectBuffer[(i * 4) + 1];

                selectedObject = selectBuffer[(i * 4) + 3];
            }
        }

        return selectedObject;
    }

    return 0;
}

void CApplication::Quit()
{
  
    SDL_Quit();
    
}

CApplication::~CApplication()
{
  
    delete (Othello_InitDisplay);
    delete (Othello_Display);
    delete (Othello_Texture);
    delete (Othello_Event);
    delete (Othello_Game);
    delete (Othello_Gui);
    
}

