// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// FAUVART Sbastien	<seb.fauvart@free.fr>
// Mon May 19 12:57:45 2003


#include "../include/cfont.h"

CFont::CFont()
{
  
}

void CFont::DrawText(int Xorigin, int Yorigin, int _texture, const char *strString)
{
  int     j = 0, k = 0;
  float   umin, umax, vmin, vmax;
  float   unitChars = 0.125f;


  if (strString == NULL)
    return;

  glBindTexture(GL_TEXTURE_2D, g_Texture[_texture]);

  for (int i=0; i < (int)strlen(strString); i++)
  {
    switch(strString[i])
    {
    case 'A':     j=k=0; break;
    case 'B':     j=1; k=0; break;
    case 'C':     j=2; k=0; break;
    case 'D':     j=3; k=0; break;
    case 'E':     j=4; k=0; break;
    case 'F':     j=5; k=0; break;
    case 'G':     j=6; k=0; break;
    case 'H':     j=7; k=0; break;
    case 'I':     j=0; k=1; break;
    case 'J':     j=1; k=1; break;
    case 'K':     j=2; k=1; break;
    case 'L':     j=3; k=1; break;
    case 'M':     j=4; k=1; break;
    case 'N':     j=5; k=1; break;
    case 'O':     j=6; k=1; break;
    case 'P':     j=7; k=1; break;
    case 'Q':     j=0; k=2; break;
    case 'R':     j=1; k=2; break;
    case 'S':     j=2; k=2; break;
    case 'T':     j=3; k=2; break;
    case 'U':     j=4; k=2; break;
    case 'V':     j=5; k=2; break;
    case 'W':     j=6; k=2; break;
    case 'X':     j=7; k=2; break;
    case 'Y':     j=0; k=3; break;
    case 'Z':     j=1; k=3; break;
    case '0':     j=2; k=3; break;
    case '1':     j=3; k=3; break;
    case '2':     j=4; k=3; break;
    case '3':     j=5; k=3; break;
    case '4':     j=6; k=3; break;
    case '5':     j=7; k=3; break;
    case '6':     j=0; k=4; break;
    case '7':     j=1; k=4; break;
    case '8':     j=2; k=4; break;
    case '9':     j=3; k=4; break;
    case '!':     j=4; k=4; break;
    case '?':     j=5; k=4; break;
    case ':':     j=6; k=4; break;
    case '-':     j=7; k=4; break;
    default:      j=0; k=5; break;
    }

    umin = (0.0f + ( j * unitChars ));    umax = (umin + unitChars);
    vmax = (1.0f - ( k * unitChars ));    vmin = (vmax - unitChars);

    glBegin(GL_QUADS);

    glTexCoord2f(umin, vmin);   glVertex2i(Xorigin+(i*1), Yorigin);
    glTexCoord2f(umin, vmax);   glVertex2i(Xorigin+(i*1), Yorigin+1);
    glTexCoord2f(umax, vmax);   glVertex2i(Xorigin+1+(i*1), Yorigin+1);
    glTexCoord2f(umax, vmin);   glVertex2i(Xorigin+1+(i*1), Yorigin);

    glEnd();
  }
}

void CFont::DrawIntNumber(int Xorigin, int Yorigin, int _texture, int number)
{
  int unite;

    if(number > 59)
    {
      unite = (number - 60);
      DrawText(Xorigin, Yorigin, _texture, "6");
    }
    else if(number > 49)
    {
      unite = (number - 50);
      DrawText(Xorigin, Yorigin, _texture, "5");
    }
    else if(number > 39)
    {
      unite = (number - 40);
      DrawText(Xorigin, Yorigin, _texture, "4");
    }
    else if(number > 29)
    {
      unite = (number - 30);
      DrawText(Xorigin, Yorigin, _texture, "3");
    }
    else if(number > 19)
    {
      unite = (number - 20);
      DrawText(Xorigin, Yorigin, _texture, "2");
    }
    else if(number > 9)
    {
      unite = (number - 10);
      DrawText(Xorigin, Yorigin, _texture, "1");
    }
    else
    {
      unite = number;
      DrawText(Xorigin, Yorigin, _texture, "0");
    }

    switch(unite)
    {
      case 0:  DrawText(Xorigin + 1, Yorigin, _texture, "0"); break;
      case 1:  DrawText(Xorigin + 1, Yorigin, _texture, "1"); break;
      case 2:  DrawText(Xorigin + 1, Yorigin, _texture, "2"); break;
      case 3:  DrawText(Xorigin + 1, Yorigin, _texture, "3"); break;
      case 4:  DrawText(Xorigin + 1, Yorigin, _texture, "4"); break;
      case 5:  DrawText(Xorigin + 1, Yorigin, _texture, "5"); break;
      case 6:  DrawText(Xorigin + 1, Yorigin, _texture, "6"); break;
      case 7:  DrawText(Xorigin + 1, Yorigin, _texture, "7"); break;
      case 8:  DrawText(Xorigin + 1, Yorigin, _texture, "8"); break;
      case 9:  DrawText(Xorigin + 1, Yorigin, _texture, "9"); break;
    }
}

void CFont::Draw_Contour(float Xorigin, float Yorigin, float Xdest, float Ydest)
{

    glBindTexture(GL_TEXTURE_2D, g_Texture[bordure_texture]);

      glPushMatrix();
        glBegin(GL_QUADS);

        glTexCoord2f(0.5f, 0.0f);   glVertex3f(Xorigin  , Yorigin-1, -0.1f);
        glTexCoord2f(0.0f, 0.0f);   glVertex3f(Xorigin  , Yorigin  , -0.1f);
        glTexCoord2f(0.0f, 1.0f);   glVertex3f(Xorigin+1, Yorigin  , -0.1f);
        glTexCoord2f(0.5f, 1.0f);   glVertex3f(Xorigin+1, Yorigin-1, -0.1f);

        glTexCoord2f(0.6f, 0.1f);   glVertex3f(Xorigin+1, Yorigin  , -0.1f);
        glTexCoord2f(0.6f, 0.9f);   glVertex3f(Xdest-1  , Yorigin  , -0.1f);
        glTexCoord2f(0.9f, 0.9f);   glVertex3f(Xdest-1  , Yorigin-1, -0.1f);
        glTexCoord2f(0.9f, 0.1f);   glVertex3f(Xorigin+1, Yorigin-1, -0.1f);
        
        glTexCoord2f(0.5f, 1.0f);   glVertex3f(Xdest-1, Yorigin-1, -0.1f);
        glTexCoord2f(0.0f, 1.0f);   glVertex3f(Xdest-1, Yorigin  , -0.1f);
        glTexCoord2f(0.0f, 0.0f);   glVertex3f(Xdest  , Yorigin  , -0.1f);
        glTexCoord2f(0.5f, 0.0f);   glVertex3f(Xdest  , Yorigin-1, -0.1f);

        glTexCoord2f(0.6f, 0.1f);   glVertex3f(Xdest  , Yorigin-1, -0.1f);
        glTexCoord2f(0.6f, 0.9f);   glVertex3f(Xdest-1, Yorigin-1, -0.1f);
        glTexCoord2f(0.9f, 0.9f);   glVertex3f(Xdest-1, Ydest+1  , -0.1f);
        glTexCoord2f(0.9f, 0.1f);   glVertex3f(Xdest  , Ydest+1  , -0.1f);

        glTexCoord2f(0.05f, 0.95f);   glVertex3f(Xdest-1, Ydest  , -0.1f);
        glTexCoord2f(0.5f , 0.95f);   glVertex3f(Xdest-1, Ydest+1, -0.1f);
        glTexCoord2f(0.5f , 0.0f);    glVertex3f(Xdest  , Ydest+1, -0.1f);
        glTexCoord2f(0.05f, 0.0f);    glVertex3f(Xdest  , Ydest  , -0.1f);

        glTexCoord2f(0.6f, 0.1f);   glVertex3f(Xdest-1  , Ydest  , -0.1f);
        glTexCoord2f(0.6f, 0.9f);   glVertex3f(Xdest-1  , Ydest+1, -0.1f);
        glTexCoord2f(0.9f, 0.9f);   glVertex3f(Xorigin+1, Ydest+1, -0.1f);
        glTexCoord2f(0.9f, 0.1f);   glVertex3f(Xorigin+1, Ydest  , -0.1f);

        glTexCoord2f(0.05f, 0.0f);   glVertex3f(Xorigin    , Ydest  , -0.1f);
        glTexCoord2f(0.5f , 0.0f);   glVertex3f(Xorigin    , Ydest+1, -0.1f);
        glTexCoord2f(0.5f , 0.95f);    glVertex3f(Xorigin+1, Ydest+1, -0.1f);
        glTexCoord2f(0.05f, 0.95f);    glVertex3f(Xorigin+1, Ydest  , -0.1f);

        glTexCoord2f(0.6f, 0.1f);   glVertex3f(Xorigin  , Ydest+1  , -0.1f);
        glTexCoord2f(0.6f, 0.9f);   glVertex3f(Xorigin  , Yorigin-1, -0.1f);
        glTexCoord2f(0.9f, 0.9f);   glVertex3f(Xorigin+1, Yorigin-1, -0.1f);
        glTexCoord2f(0.9f, 0.1f);   glVertex3f(Xorigin+1, Ydest+1  , -0.1f);

        glEnd();
      glPopMatrix();

}

CFont::~CFont()
{
  
}
