// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// FAUVART Sbastien	<seb.fauvart@free.fr>
// Mon May 19 12:57:45 2003


#include "../include/display.h"
#include "../include/objects3d.h"

static CObjects3d   *Othello_Objects3d = NULL;

float board_rotate_x, board_rotate_y, board_rotate_z;

CDisplay::CDisplay()
{
  
  Othello_Objects3d = new CObjects3d;
  
  board_rotate_x = 0.0f;  board_rotate_y = 0.0f;  board_rotate_z = 0.0f;
  
}

void CDisplay::PreRendu()
{
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    glLoadIdentity();

    glLightfv( GL_LIGHT0, GL_POSITION, g_LightPosition );

    gluLookAt(0, 4, 10,     0, 0, 0,     0, 1, 0);

    glInitNames();

    glPushName(0);

}

void CDisplay::DrawUnderBoard()
{

    glPushMatrix();
    
         glBindTexture(GL_TEXTURE_2D, g_Texture[socle_texture]);
         
         Othello_Objects3d->UnderBoard();
         
    glPopMatrix();

}

void CDisplay::Draw_Case(float x, float y, float z, int name_number, int texture_number, board displayboard)
{

  int xboard, yboard;

    xboard = (int)x;
    yboard = (int)z;
    
    glLoadName(name_number);

    glBegin(GL_LINES);    glEnd();

    glPushMatrix();
    
         glBindTexture(GL_TEXTURE_2D, g_Texture[texture_number]);

         Othello_Objects3d->Case(x, y, z);

    glPopMatrix();

    if(Flag_RetrieveObjectID == 0)
    {
      if(displayboard[xboard][yboard] == PLAYER_1)
      {
        glPushMatrix();
          glTranslatef(0.5f , 0.25f, 0.5f);
          glTranslatef(x , 0.0f, z);
          glScalef(0.4f, 0.4f, 0.4f);
          glBindTexture(GL_TEXTURE_2D, g_Texture[pion1_texture]);

          Othello_Objects3d->Piece_style1();

        glPopMatrix();
      }
      else if(displayboard[xboard][yboard] == PLAYER_2)
      {
        glPushMatrix();
          glTranslatef(0.5f , 0.25f, 0.5f);
          glTranslatef(x , 0.0f, z);
          glScalef(0.4f, 0.4f, 0.4f);
          glBindTexture(GL_TEXTURE_2D, g_Texture[pion2_texture]);

          Othello_Objects3d->Piece_style1();

        glPopMatrix();
      }
    }

    glEnd();
    
}

void CDisplay::DrawBoard(board displayboard)
{
  
        Draw_Case(0, 0, 0, case_A8, black_texture, displayboard);
        Draw_Case(1, 0, 0, case_B8, white_texture, displayboard);
        Draw_Case(2, 0, 0, case_C8, black_texture, displayboard);
        Draw_Case(3, 0, 0, case_D8, white_texture, displayboard);
        Draw_Case(4, 0, 0, case_E8, black_texture, displayboard);
        Draw_Case(5, 0, 0, case_F8, white_texture, displayboard);
        Draw_Case(6, 0, 0, case_G8, black_texture, displayboard);
        Draw_Case(7, 0, 0, case_H8, white_texture, displayboard);

        Draw_Case(0, 0, 1, case_A7, white_texture, displayboard);
        Draw_Case(1, 0, 1, case_B7, black_texture, displayboard);
        Draw_Case(2, 0, 1, case_C7, white_texture, displayboard);
        Draw_Case(3, 0, 1, case_D7, black_texture, displayboard);
        Draw_Case(4, 0, 1, case_E7, white_texture, displayboard);
        Draw_Case(5, 0, 1, case_F7, black_texture, displayboard);
        Draw_Case(6, 0, 1, case_G7, white_texture, displayboard);
        Draw_Case(7, 0, 1, case_H7, black_texture, displayboard);

        Draw_Case(0, 0, 2, case_A6, black_texture, displayboard);
        Draw_Case(1, 0, 2, case_B6, white_texture, displayboard);
        Draw_Case(2, 0, 2, case_C6, black_texture, displayboard);
        Draw_Case(3, 0, 2, case_D6, white_texture, displayboard);
        Draw_Case(4, 0, 2, case_E6, black_texture, displayboard);
        Draw_Case(5, 0, 2, case_F6, white_texture, displayboard);
        Draw_Case(6, 0, 2, case_G6, black_texture, displayboard);
        Draw_Case(7, 0, 2, case_H6, white_texture, displayboard);

        Draw_Case(0, 0, 3, case_A5, white_texture, displayboard);
        Draw_Case(1, 0, 3, case_B5, black_texture, displayboard);
        Draw_Case(2, 0, 3, case_C5, white_texture, displayboard);
        Draw_Case(3, 0, 3, case_D5, black_texture, displayboard);
        Draw_Case(4, 0, 3, case_E5, white_texture, displayboard);
        Draw_Case(5, 0, 3, case_F5, black_texture, displayboard);
        Draw_Case(6, 0, 3, case_G5, white_texture, displayboard);
        Draw_Case(7, 0, 3, case_H5, black_texture, displayboard);

        Draw_Case(0, 0, 4, case_A4, black_texture, displayboard);
        Draw_Case(1, 0, 4, case_B4, white_texture, displayboard);
        Draw_Case(2, 0, 4, case_C4, black_texture, displayboard);
        Draw_Case(3, 0, 4, case_D4, white_texture, displayboard);
        Draw_Case(4, 0, 4, case_E4, black_texture, displayboard);
        Draw_Case(5, 0, 4, case_F4, white_texture, displayboard);
        Draw_Case(6, 0, 4, case_G4, black_texture, displayboard);
        Draw_Case(7, 0, 4, case_H4, white_texture, displayboard);

        Draw_Case(0, 0, 5, case_A3, white_texture, displayboard);
        Draw_Case(1, 0, 5, case_B3, black_texture, displayboard);
        Draw_Case(2, 0, 5, case_C3, white_texture, displayboard);
        Draw_Case(3, 0, 5, case_D3, black_texture, displayboard);
        Draw_Case(4, 0, 5, case_E3, white_texture, displayboard);
        Draw_Case(5, 0, 5, case_F3, black_texture, displayboard);
        Draw_Case(6, 0, 5, case_G3, white_texture, displayboard);
        Draw_Case(7, 0, 5, case_H3, black_texture, displayboard);

        Draw_Case(0, 0, 6, case_A2, black_texture, displayboard);
        Draw_Case(1, 0, 6, case_B2, white_texture, displayboard);
        Draw_Case(2, 0, 6, case_C2, black_texture, displayboard);
        Draw_Case(3, 0, 6, case_D2, white_texture, displayboard);
        Draw_Case(4, 0, 6, case_E2, black_texture, displayboard);
        Draw_Case(5, 0, 6, case_F2, white_texture, displayboard);
        Draw_Case(6, 0, 6, case_G2, black_texture, displayboard);
        Draw_Case(7, 0, 6, case_H2, white_texture, displayboard);

        Draw_Case(0, 0, 7, case_A1, white_texture, displayboard);
        Draw_Case(1, 0, 7, case_B1, black_texture, displayboard);
        Draw_Case(2, 0, 7, case_C1, white_texture, displayboard);
        Draw_Case(3, 0, 7, case_D1, black_texture, displayboard);
        Draw_Case(4, 0, 7, case_E1, white_texture, displayboard);
        Draw_Case(5, 0, 7, case_F1, black_texture, displayboard);
        Draw_Case(6, 0, 7, case_G1, white_texture, displayboard);
        Draw_Case(7, 0, 7, case_H1, black_texture, displayboard);

}

void CDisplay::PostRendu()
{

    SDL_GL_SwapBuffers();

}

CDisplay::~CDisplay()
{

  delete (Othello_Objects3d);
  
}

