// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// FAUVART Sbastien	<seb.fauvart@free.fr>
// Mon May 19 12:57:45 2003


#include "../include/init_display.h"
#include "../include/variables.h"

SDL_Surface * MainWindow;

float g_LightPosition[4] = { 4, 7, 4, 1 };
float ambience[4] = { 0.3f, 0.3f, 0.3f, 1.0 };
float diffuse[4] = { 0.5f, 0.5f, 0.5f, 1.0 };
int VideoFlags;

typedef unsigned char uchar;

CInitDisplay::CInitDisplay()
{

}

int CInitDisplay::initSDL(int width, int height, int bpp, int fullscreen, int mode, int audio)
{

    if( SDL_Init( SDL_INIT_VIDEO ) < 0 )
    {
       cerr << "Failed initializing SDL Video : " << SDL_GetError( ) << endl;
       return 1;
    }

    const SDL_VideoInfo * VideoInfo = SDL_GetVideoInfo();

    if(VideoInfo == NULL)
    {
       cerr << "Failed getting Video Info : " << SDL_GetError() << endl;
       return 1;
    }

        VideoFlags  = SDL_OPENGL;
        VideoFlags |= SDL_HWPALETTE;
        VideoFlags |= SDL_RESIZABLE;

    if(VideoInfo -> hw_available)
        VideoFlags |= SDL_HWSURFACE;
    else
        VideoFlags |= SDL_SWSURFACE;

    if(VideoInfo -> blit_hw)
        VideoFlags |= SDL_HWACCEL;
        
    if(fullscreen)
        VideoFlags |= SDL_FULLSCREEN;


    SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 );
    SDL_GL_SetAttribute( SDL_GL_DEPTH_SIZE,   bpp);
    SDL_GL_SetAttribute( SDL_GL_STENCIL_SIZE, 0);
    SDL_GL_SetAttribute( SDL_GL_ACCUM_RED_SIZE, 0);
    SDL_GL_SetAttribute( SDL_GL_ACCUM_GREEN_SIZE, 0);
    SDL_GL_SetAttribute( SDL_GL_ACCUM_BLUE_SIZE, 0);
    SDL_GL_SetAttribute( SDL_GL_ACCUM_ALPHA_SIZE, 0);

    MainWindow = SDL_SetVideoMode(width, height, bpp, VideoFlags);

    if( MainWindow == NULL )
    {
        cerr << "Failed to Create Window : " << SDL_GetError() << endl;
        return 1;
    }

    SDL_WM_SetCaption("Da Othello 3D", "DaOthello3D");
    
    initOpenGl();
    if (height==0)
    {
        height=1;
    }

    glViewport(0, 0, width, height);


    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();

    gluPerspective(45.0f, (GLfloat)width/(GLfloat)height, 0.5f, 500.0f);

    glMatrixMode(GL_MODELVIEW);
    glLoadIdentity();
    
    return 0;

}

int CInitDisplay::initOpenGl()
{

    glLightfv( GL_LIGHT0, GL_AMBIENT,  ambience );
    glLightfv( GL_LIGHT0, GL_DIFFUSE,  diffuse );
    glLightfv( GL_LIGHT0, GL_POSITION, g_LightPosition );

    glShadeModel(GL_SMOOTH);
    glClearColor(0.00f, 0.00f, 0.00f, 0.0f);
    glClearDepth(1.0f);
    glDepthFunc(GL_LEQUAL);
    glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
    
    glEnable ( GL_LIGHT0   );
    glEnable ( GL_LIGHTING );
    glEnable ( GL_DEPTH_TEST );
    glEnable ( GL_TEXTURE_2D );
    
    return 0;
}

int CInitDisplay::resizeGLScene(int width, int height, int bpp)
{
    MainWindow = SDL_SetVideoMode( width, height, bpp, VideoFlags );

    if (height==0)
    {
        height=1;
    }

    glViewport(0, 0, width, height);


    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();

    gluPerspective(45.0f, (GLfloat)width/(GLfloat)height, 0.5f, 500.0f);

    glMatrixMode(GL_MODELVIEW);
    glLoadIdentity();

    return 0;
}

int CInitDisplay::destroyWindow()
{

    SDL_Quit();
    
    return 0;
}

CInitDisplay::~CInitDisplay()
{

    destroyWindow();

}
