// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// FAUVART Sbastien	<seb.fauvart@free.fr>
// Mon May 19 12:57:45 2003


#include "../include/texture.h"
#include "../include/variables.h"

unsigned int g_Texture[MAX_TEXTURES];

CTexture::CTexture()
{

}

void CTexture::swap(unsigned char & a, unsigned char & b)
{
    unsigned char temp;

    temp = a;
    a    = b;
    b    = temp;

    return;
}

int CTexture::CreateTexture(unsigned int textureArray[], char *strFileName, int textureID)
{

    SDL_Surface *pBitmap[1];

    if( strFileName == NULL )
        return 1;

    pBitmap[0] = SDL_LoadBMP(strFileName);

    if(pBitmap[0] == NULL)
    {
        cerr << " Failed loading " << strFileName << " : " << SDL_GetError() << endl;
        return 1;
    }

    glGenTextures(1, &textureArray[textureID]);

    glBindTexture(GL_TEXTURE_2D, textureArray[textureID]);

    int width  = pBitmap[0] -> w;
    int height = pBitmap[0] -> h;
    unsigned char * data = (unsigned char *) (pBitmap[0] -> pixels);

    int BytesPerPixel = (pBitmap[0] -> format -> BytesPerPixel);

    for( int i = 0 ; i < (height / 2) ; ++i )
        for( int j = 0 ; j < width * BytesPerPixel; j += BytesPerPixel )
            for(int k = 0; k < BytesPerPixel; ++k)
                swap( data[ (i * width * BytesPerPixel) + j + k], data[ ( (height - i - 1) * width * BytesPerPixel ) + j + k]);

    gluBuild2DMipmaps(GL_TEXTURE_2D, 3, pBitmap[0]->w, pBitmap[0]->h, GL_BGR_EXT , GL_UNSIGNED_BYTE, pBitmap[0]->pixels);

    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST);

    SDL_FreeSurface(pBitmap[0]);

    return 0;

}

int CTexture::InitTextures()
{
  
    if ( CreateTexture(g_Texture, "../data/white.bmp", white_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/black.bmp", black_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/pion1.bmp", pion1_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/pion2.bmp", pion2_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/chars.bmp", chars_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/chars2.bmp", chars2_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/texture1.bmp", bordure_texture) )
      return 1;
	
    if ( CreateTexture(g_Texture, "../data/wood.bmp", socle_texture) )
      return 1;

    return 0;
}

CTexture::~CTexture()
{

  if (g_Texture[white_texture])
    glDeleteTextures(1, &g_Texture[white_texture]);
  
  if (g_Texture[black_texture])
    glDeleteTextures(1, &g_Texture[black_texture]);
  
  if (g_Texture[pion1_texture])
    glDeleteTextures(1, &g_Texture[pion1_texture]);
  
  if (g_Texture[pion2_texture])
    glDeleteTextures(1, &g_Texture[pion2_texture]);
  
  if (g_Texture[chars_texture])
    glDeleteTextures(1, &g_Texture[chars_texture]);
  
  if (g_Texture[chars2_texture])
    glDeleteTextures(1, &g_Texture[chars2_texture]);
  
  if (g_Texture[bordure_texture])
    glDeleteTextures(1, &g_Texture[bordure_texture]);
  
  if (g_Texture[socle_texture])
    glDeleteTextures(1, &g_Texture[socle_texture]);
  
}
